@@ -104,9 +104,24 @@ for dtype in list(encoding_map.values()):
     encoding_map[dtype] = dtype
 
 
+def coerce_array(array, dtype):
+    array = np.asanyarray(array).astype(dtype, copy=False)
+    if dtype == np.bytes_:
+        array = build_null_terminated_string_byte_array(array)
+    return array
+
+
+def build_null_terminated_string_byte_array(array):
+    buff = bytearray()
+    for t in array:
+        buff.extend(t)
+        buff.extend(b"\0")
+    return np.asanyarray(buff).astype(dtype=np.uint8, copy=False)
+
+
 def encode_array(array, compression=COMPRESSION_NONE, dtype=np.float32):
     if compression == COMPRESSION_LINEAR or compression == COMPRESSION_DELTA:
-        array = np.asanyarray(array).astype(dtype, copy=False)
+        array = coerce_array(array, dtype)
         if compression == COMPRESSION_LINEAR:
             array = linear_encode(array, copy=True)
         else:
@@ -117,7 +132,7 @@ def encode_array(array, compression=COMPRESSION_NONE, dtype=np.float32):
     elif compression.startswith("MS-Numpress"):
         if pynumpress is None:
             raise ImportError("pynumpress is not installed, required for MS-Numpress compression")
-        array = np.asanyarray(array).astype(dtype, copy=False)
+        array = coerce_array(array, dtype)
         if compression == COMPRESSION_NUMPRESS_SHORT_LOGGED_FLOAT:
             fixed_point = pynumpress.optimal_slof_fixed_point(array)
             array = pynumpress.encode_slof(array, fixed_point)
@@ -130,7 +145,7 @@ def encode_array(array, compression=COMPRESSION_NONE, dtype=np.float32):
         # Now don't apply any additional encoding to the generated bytestring
         compression = COMPRESSION_NONE
     else:
-        bytestring = np.asanyarray(array).astype(dtype, copy=False).tobytes()
+        bytestring = coerce_array(array, dtype).tobytes()
     if compression == COMPRESSION_NONE:
         bytestring = bytestring
     elif compression == COMPRESSION_ZLIB:
@@ -142,7 +157,7 @@ def encode_array(array, compression=COMPRESSION_NONE, dtype=np.float32):
 
 
 def encode_array_direct(array, compression=COMPRESSION_NONE, dtype=np.float32):
-    array = np.asanyarray(array).astype(dtype, copy=False)
+    array = coerce_array(array, dtype)
     if compression == COMPRESSION_LINEAR:
         array = linear_encode(array, copy=True)
     elif compression == COMPRESSION_DELTA:
